@@ -78,9 +78,6 @@ import com.openexchange.tools.session.ServerSession;
  */
 public final class MyServlet extends DataServlet {
 
-    /**
-     *
-     */
     private static final long serialVersionUID = -8914926421736440078L;
 
     private static final Logger LOG = org.slf4j.LoggerFactory.getLogger(MyServlet.class);
@@ -95,21 +92,17 @@ public final class MyServlet extends DataServlet {
     }
 
     @Override
-    protected void doGet(final HttpServletRequest req,
-        final HttpServletResponse resp) throws ServletException,
-        IOException {
-
+    protected void doGet(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
         final Response response = new Response();
         final Session session = getSessionObject(req);
 
         try {
-
-            final String action = parseMandatoryStringParameter(req,PARAMETER_ACTION);
+            final String action = parseMandatoryStringParameter(req, PARAMETER_ACTION);
             JSONObject jsonObj;
 
             try {
                 jsonObj = convertParameter2JSONObject(req);
-            } catch (final JSONException e) {
+            } catch (JSONException e) {
                 LOG.error("", e);
                 response.setException(OXJSONExceptionCodes.JSON_BUILD_ERROR.create(e));
                 writeResponse(response, resp, session);
@@ -117,20 +110,17 @@ public final class MyServlet extends DataServlet {
             }
             final Context ctx = ContextStorage.getInstance().getContext(session);
             final MyServletRequest proRequest = new MyServletRequest(session, ctx);
-            final Object responseObj = proRequest.action(action, jsonObj,req);
+            final Object responseObj = proRequest.action(action, jsonObj);
             response.setData(responseObj);
-
-        } catch (final OXException e) {
+        } catch (OXException e) {
             LOG.error("", e);
             response.setException(e);
-        } catch (final JSONException e) {
+        } catch (JSONException e) {
             final OXException oje = OXJSONExceptionCodes.JSON_WRITE_ERROR.create(e);
             LOG.error("", oje);
             response.setException(oje);
         }
 
         writeResponse(response, resp, session);
-
     }
-
 }
